@@ -69,7 +69,7 @@ This command expects to be bound to \"g\" in `comint-mode'."
            (equal (this-command-keys) "g"))
       (self-insert-command 1)
     (let ((dd default-directory)
-          (cmd (car compilation-arguments)))
+          (cmd (string-trim (car compilation-arguments))))
       (erase-buffer)
       (let ((default-directory dd))
         (if (string-match "cook \\(:[^ ]+\\) \\(.*\\)\\'" cmd)
@@ -218,7 +218,7 @@ When ARG is non-nil, open Cookbook.py instead."
                                (file-name-directory book))))
          (recipes
           (split-string (shell-command-to-string
-                         (concat cook-cmd " --list")) "\n" t))
+                         (concat cook-cmd " --list")) "\n" t " "))
          (recipes-alist
           (mapcar (lambda (s) (cons (car (split-string s " :")) s)) recipes))
          (recipe (or recipe
