@@ -45,11 +45,17 @@ def book_config(book):
     return {}
 
 def recipe_args_description(f):
-    arity = recipe_arity(f)
-    if arity == 0:
-        return ""
-    else:
-        return " " + " ".join([":" + a for a in function_arglist(f)[1:]])
+    spec = inspect.getfullargspec(f)
+    res = []
+    ld = len(spec.defaults) if spec.defaults else 0
+    d = len(spec.args) - ld - 1
+
+    for (i, a) in enumerate(spec.args[1:]):
+        if i >= d:
+            res.append(":" + a + "=" + str(spec.defaults[i - d]))
+        else:
+            res.append(":" + a)
+    return " " + " ".join(res)
 
 def recipe_names(book):
     di = recipe_dict(book)
@@ -144,7 +150,7 @@ def _main(book, module, flags, args):
         fun = recipe_dict(book)[recipe]
         cfg = book_config(book)
         if "tee" in cfg and recipe != "bash":
-            basedir = cfg["tee"]["location"]
+            basedir = os.path.expanduser(cfg["tee"]["location"])
             fname = log_file_name(basedir, book, recipe)
             el.barf(fname, lf("Book: {book}\nRecipe: {recipe}\n"))
             tee = subprocess.Popen(["setsid", "-w", "tee", "-a", fname], stdin=subprocess.PIPE)
@@ -170,7 +176,12 @@ def _main(book, module, flags, args):
             sys.stdout = sys.__stdout__
             print("\n".join([cmd[2:] for cmd in log.cmds] + ret_cmds))
         else:
-            print("\n".join(log.cmds))
+            if len(log.cmds) < 10:
+                spec = inspect.getfullargspec(fun)
+                if ("log" in spec.args) and spec.defaults and spec.defaults[spec.args.index("log") - 1] is None:
+                    pass
+                else:
+                    print("\n".join(log.cmds))
             if ret_cmds:
                 el.bash(ret_cmds, echo=True)
 
@@ -291,7 +302,8 @@ def complete(argv=None):
         fun = recipe_dict(mod)[args[2]]
         part = args[-1]
         fun_args = function_arglist(fun)
-        if len(fun_args) == 2 and fun_args[1] in ["fname", "fnames"]:
+        arg_idx = len(args) - 3
+        if arg_idx < len(fun_args) and fun_args[arg_idx] in ["fname", "fnames"]:
             print(el.sc("compgen -f -- {part}"))
         else:
             args = [""]*recipe_arity(fun)
