@@ -182,14 +182,15 @@ def file_exists_p(f):
     (host, fname) = parse_fname(f)
     if host is not None:
         with hostname(host):
-            return sc(
+            res = sc(
                 "stat {fname} 2>/dev/null || echo Fail",
-                desc = (host, "stat " + fname)) != "Fail"
+                desc=(host, "stat " + fname))
+            return res != "Fail"
     else:
         return os.path.exists(expand_file_name(fname))
 
 def file_newer_than_file_p(f1, f2):
-    return os.path.getctime(f1) > os.path.getctime(f2)
+    return os.path.getmtime(f1) > os.path.getmtime(f2)
 
 def file_directory_p(f):
     return os.path.isdir(f)
@@ -226,6 +227,8 @@ def slurp(f):
         try:
             with open(expand_file_name(f), 'r') as fh:
                 return fh.read()
+        except PermissionError:
+            return sc("sudo cat {fname}")
         except UnicodeDecodeError:
             with codecs.open(
                     expand_file_name(f), 'r',
@@ -308,19 +311,17 @@ def bash(cmd, echo=False, capture=False, **kwargs):
             part = p.stdout.read().decode()
             if part == "" and p.poll() is not None:
                 break
-            else:
-                out += part
-                if echo:
-                    print(part, end="")
+            out += part
+            if echo:
+                print(part, end="")
         err = ""
         while True:
             part = p.stderr.read().decode()
             if part == "" and p.poll() is not None:
                 break
-            else:
-                err += part
-                if echo:
-                    print(part, end="")
+            err += part
+            if echo:
+                print(part, end="")
         if p.returncode == 0:
             return err + out
         else:
